@@ -32,6 +32,7 @@
 #include "kis_adjustment_layer.h"
 #include "kis_filter_mask.h"
 #include "kis_selection.h"
+#include "kis_paint_device_debug_utils.h"
 
 #include "filter/kis_filter.h"
 #include "filter/kis_filter_configuration.h"
@@ -65,7 +66,7 @@ void KisAsyncMergerTest::testMerger()
 
     KisFilterSP filter = KisFilterRegistry::instance()->value("blur");
     Q_ASSERT(filter);
-    KisFilterConfigurationSP configuration = filter->defaultConfiguration(0);
+    KisFilterConfigurationSP configuration = filter->defaultConfiguration();
     Q_ASSERT(configuration);
 
     KisLayerSP paintLayer1 = new KisPaintLayer(image, "paint1", OPACITY_OPAQUE_U8, device1);
@@ -186,7 +187,7 @@ void KisAsyncMergerTest::testFullRefreshWithClones()
 
     KisFilterSP filter = KisFilterRegistry::instance()->value("invert");
     Q_ASSERT(filter);
-    KisFilterConfigurationSP configuration = filter->defaultConfiguration(0);
+    KisFilterConfigurationSP configuration = filter->defaultConfiguration();
     Q_ASSERT(configuration);
 
     KisLayerSP paintLayer1 = new KisPaintLayer(image, "paint1", OPACITY_OPAQUE_U8, device1);
@@ -287,5 +288,164 @@ void KisAsyncMergerTest::testSubgraphingWithoutUpdatingParent()
     }
 }
 
+
+#include <KoCompositeOpRegistry.h>
+
+enum DependentNodeType {
+    GROUP_LAYER,
+    ADJUSTMENT_LAYER
+};
+
+/*
+  +--------------+
+  |root          |
+  | (blur1)      |
+  | group        |
+  |  blur_mask   |
+  |  paint 2     |
+  |  paint 3     |
+  | paint 1      |
+  +--------------+
+ */
+void testFullRefreshForDependentNodes(const DependentNodeType dependentNode,
+                                      const bool useFilterMask,
+                                      const bool useLayerStyle)
+{
+    const QRect imageRect = QRect(0, 0, 128, 128);
+    const QRect fillRect = QRect(32, 32, 64, 64);
+    const QRect smallRect = QRect(60, 60, 8, 8);
+
+    const KoColorSpace *colorSpace = KoColorSpaceRegistry::instance()->rgb8();
+    KisImageSP image = new KisImage(0, imageRect.width(), imageRect.height(), colorSpace, "blur test");
+
+    KisPaintDeviceSP device1 = new KisPaintDevice(colorSpace);
+
+    if (dependentNode == GROUP_LAYER && !useLayerStyle) {
+        device1->fill(imageRect, KoColor(Qt::black, colorSpace));
+    }
+
+    KisLayerSP paintLayer1 = new KisPaintLayer(image, "paint1", OPACITY_OPAQUE_U8, device1);
+
+    KisPaintDeviceSP device2 = new KisPaintDevice(colorSpace);
+    device2->fill(fillRect, KoColor(Qt::white, colorSpace));
+    KisLayerSP paintLayer2 = new KisPaintLayer(image, "paint2", OPACITY_OPAQUE_U8, device2);
+
+    device2->fill(QRect(63, 0, 1, 64), KoColor(Qt::green, colorSpace));
+
+    KisPaintDeviceSP device3 = new KisPaintDevice(colorSpace);
+    device3->fill(smallRect, KoColor(Qt::red, colorSpace));
+    KisLayerSP paintLayer3 = new KisPaintLayer(image, "paint3", OPACITY_OPAQUE_U8, device3);
+
+    KisLayerSP groupLayer = new KisGroupLayer(image, "group", OPACITY_OPAQUE_U8);
+
+
+    image->addNode(paintLayer1, image->rootLayer());
+    image->addNode(groupLayer, image->rootLayer());
+    image->addNode(paintLayer2, groupLayer);
+    image->addNode(paintLayer3, groupLayer);
+
+    KisLayerSP testingLayer = groupLayer;
+
+    if (dependentNode == ADJUSTMENT_LAYER) {
+        KisFilterSP filter = KisFilterRegistry::instance()->value("blur");
+        KIS_ASSERT(filter);
+        KisFilterConfigurationSP configuration = filter->defaultConfiguration();
+        KIS_ASSERT(configuration);
+
+        KisLayerSP blur1 = new KisAdjustmentLayer(image, "blur1", configuration, 0);
+        blur1->setCompositeOpId(COMPOSITE_OVER);
+
+        image->addNode(blur1, image->rootLayer());
+    }
+
+    if (useFilterMask) {
+        KisFilterSP filter = KisFilterRegistry::instance()->value("blur");
+        KIS_ASSERT(filter);
+        KisFilterConfigurationSP configuration = filter->defaultConfiguration();
+        KIS_ASSERT(configuration);
+
+        KisFilterMaskSP blurMask1 = new KisFilterMask();
+        blurMask1->initSelection(groupLayer);
+        blurMask1->setFilter(configuration);
+        image->addNode(blurMask1, testingLayer);
+    }
+
+    if (useLayerStyle) {
+        KisPSDLayerStyleSP style(new KisPSDLayerStyle());
+
+        style->context()->keep_original = true;
+        style->dropShadow()->setEffectEnabled(true);
+        style->dropShadow()->setDistance(9);
+        style->dropShadow()->setSpread(100);
+        style->dropShadow()->setSize(9);
+        style->dropShadow()->setNoise(0);
+        style->dropShadow()->setKnocksOut(false);
+        style->dropShadow()->setOpacity(90);
+        style->dropShadow()->setAngle(0);
+
+        testingLayer->setLayerStyle(style);
+    }
+
+
+    QRect cropRect(image->bounds());
+
+    KisFullRefreshWalker walker(cropRect);
+    KisAsyncMerger merger;
+
+
+    QVector<QRect> patchRects;
+    patchRects << QRect(0,0,64,64);
+    patchRects << QRect(64,0,64,64);
+    patchRects << QRect(0,64,64,64);
+    patchRects << QRect(64,64,64,64);
+
+    Q_FOREACH(const QRect &rc, patchRects) {
+        walker.collectRects(image->rootLayer(), rc);
+        merger.startMerge(walker);
+    }
+
+    // Wait for additional jobs generated by the clone are finished
+    image->waitForDone();
+
+    QString testName = dependentNode == GROUP_LAYER ? "group" : "adj";
+
+    if (useFilterMask) {
+        testName += "_mask";
+    }
+
+    if (useLayerStyle) {
+        testName += "_style";
+    }
+
+    TestUtil::checkQImage(image->projection()->convertToQImage(0, imageRect),
+                          "async_merger_test", "dependent", testName, 3);
+}
+
+void KisAsyncMergerTest::testFullRefreshGroupWithMask()
+{
+    testFullRefreshForDependentNodes(GROUP_LAYER, true, false);
+}
+
+void KisAsyncMergerTest::testFullRefreshGroupWithStyle()
+{
+    testFullRefreshForDependentNodes(GROUP_LAYER, false, true);
+}
+
+void KisAsyncMergerTest::testFullRefreshGroupWithMaskAndStyle()
+{
+    testFullRefreshForDependentNodes(GROUP_LAYER, true, true);
+}
+
+void KisAsyncMergerTest::testFullRefreshAdjustmentWithMask()
+{
+    testFullRefreshForDependentNodes(ADJUSTMENT_LAYER, true, false);
+}
+
+void KisAsyncMergerTest::testFullRefreshAdjustmentWithStyle()
+{
+    testFullRefreshForDependentNodes(ADJUSTMENT_LAYER, false, true);
+}
+
+
 QTEST_MAIN(KisAsyncMergerTest)
 
