@@ -152,7 +152,7 @@ struct KoColorSpaceTrait {
     }
 
     inline static void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels) {
-        Q_ASSERT((int)channels.count() == (int)channels_nb);
+        Q_ASSERT((int)channels.count() >= (int)channels_nb);
         channels_type c;
         for (uint i = 0; i < channels_nb; i++) {
             c = nativeArray(pixel)[i];
@@ -161,7 +161,7 @@ struct KoColorSpaceTrait {
     }
 
     inline static void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) {
-        Q_ASSERT((int)values.count() == (int)channels_nb);
+        Q_ASSERT((int)values.count() >= (int)channels_nb);
         channels_type c;
         for (uint i = 0; i < channels_nb; i++) {
             float b = qBound((float)KoColorSpaceMathsTraits<channels_type>::min,
