@@ -55,12 +55,12 @@ KisCurveOptionWidget::KisCurveOptionWidget(KisCurveOption* curveOption, const QS
     updateSensorCurveLabels(m_curveOptionWidget->sensorSelector->currentHighlighted());
     updateCurve(m_curveOptionWidget->sensorSelector->currentHighlighted());
 
-    connect(m_curveOptionWidget->curveWidget, SIGNAL(modified()), this, SLOT(transferCurve()));
+    connect(m_curveOptionWidget->curveWidget, SIGNAL(modified()), this, SLOT(slotModified()));
     connect(m_curveOptionWidget->sensorSelector, SIGNAL(parametersChanged()), SLOT(emitSettingChanged()));
     connect(m_curveOptionWidget->sensorSelector, SIGNAL(parametersChanged()), SLOT(updateLabelsOfCurrentSensor()));
-    connect(m_curveOptionWidget->sensorSelector, SIGNAL(highlightedSensorChanged(KisDynamicSensorSP )), SLOT(updateSensorCurveLabels(KisDynamicSensorSP )));
-    connect(m_curveOptionWidget->sensorSelector, SIGNAL(highlightedSensorChanged(KisDynamicSensorSP )), SLOT(updateCurve(KisDynamicSensorSP )));
-    connect(m_curveOptionWidget->checkBoxUseSameCurve, SIGNAL(stateChanged(int)), SLOT(transferCurve()));
+    connect(m_curveOptionWidget->sensorSelector, SIGNAL(highlightedSensorChanged(KisDynamicSensorSP)), SLOT(updateSensorCurveLabels(KisDynamicSensorSP)));
+    connect(m_curveOptionWidget->sensorSelector, SIGNAL(highlightedSensorChanged(KisDynamicSensorSP)), SLOT(updateCurve(KisDynamicSensorSP)));
+    connect(m_curveOptionWidget->checkBoxUseSameCurve, SIGNAL(stateChanged(int)), SLOT(slotStateChanged()));
 
 
     // set all the icons for the curve preset shapes
@@ -80,18 +80,20 @@ KisCurveOptionWidget::KisCurveOptionWidget(KisCurveOption* curveOption, const QS
     m_curveOptionWidget->label_ymin->setText(minLabel);
     m_curveOptionWidget->label_ymax->setText(maxLabel);
 
-    m_curveOptionWidget->slider->setRange(curveOption->minValue(), curveOption->maxValue(), 2);
-    m_curveOptionWidget->slider->setValue(curveOption->value());
+    // strength settings is shown as 0-100%
+    m_curveOptionWidget->strengthSlider->setRange(curveOption->minValue()*100, curveOption->maxValue()*100, 0);
+    m_curveOptionWidget->strengthSlider->setValue(curveOption->value()*100);
+    m_curveOptionWidget->strengthSlider->setPrefix(i18n("Strength: "));
+    m_curveOptionWidget->strengthSlider->setSuffix(i18n("%"));
+
 
     if (hideSlider) {
-         m_curveOptionWidget->slider->hide();
-         m_curveOptionWidget->strengthLabel->hide();
+         m_curveOptionWidget->strengthSlider->hide();
     }
 
-
     connect(m_curveOptionWidget->checkBoxUseCurve, SIGNAL(stateChanged(int))  , SLOT(updateValues()));
     connect(m_curveOptionWidget->curveMode, SIGNAL(currentIndexChanged(int)), SLOT(updateMode()));
-    connect(m_curveOptionWidget->slider, SIGNAL(valueChanged(qreal)), SLOT(updateValues()));
+    connect(m_curveOptionWidget->strengthSlider, SIGNAL(valueChanged(qreal)), SLOT(updateValues()));
 }
 
 KisCurveOptionWidget::~KisCurveOptionWidget()
@@ -112,7 +114,7 @@ void KisCurveOptionWidget::readOptionSetting(const KisPropertiesConfigurationSP
     m_curveOption->readOptionSetting(setting);
 
     m_curveOptionWidget->checkBoxUseCurve->setChecked(m_curveOption->isCurveUsed());
-    m_curveOptionWidget->slider->setValue(m_curveOption->value());
+    m_curveOptionWidget->strengthSlider->setValue(m_curveOption->value()*100);
     m_curveOptionWidget->checkBoxUseSameCurve->setChecked(m_curveOption->isSameCurveUsed());
     m_curveOptionWidget->curveMode->setCurrentIndex(m_curveOption->getCurveMode());
 
@@ -122,6 +124,11 @@ void KisCurveOptionWidget::readOptionSetting(const KisPropertiesConfigurationSP
     m_curveOptionWidget->sensorSelector->setCurrent(m_curveOption->activeSensors().first());
     updateSensorCurveLabels(m_curveOptionWidget->sensorSelector->currentHighlighted());
     updateCurve(m_curveOptionWidget->sensorSelector->currentHighlighted());
+
+    if (m_curveOption->isSameCurveUsed()) {
+        // make sure the curve is transfered to all sensors to avoid updating from a wrong curve later
+        transferCurve();
+    }
 }
 
 void KisCurveOptionWidget::lodLimitations(KisPaintopLodLimitations *l) const
@@ -154,6 +161,17 @@ QWidget* KisCurveOptionWidget::curveWidget()
     return m_widget;
 }
 
+void KisCurveOptionWidget::slotModified()
+{
+    transferCurve();
+}
+
+void KisCurveOptionWidget::slotStateChanged()
+{
+    transferCurve();
+}
+
+
 void KisCurveOptionWidget::transferCurve()
 {
     m_curveOptionWidget->sensorSelector->setCurrentCurve(m_curveOptionWidget->curveWidget->curve(), m_curveOptionWidget->checkBoxUseSameCurve->isChecked());
@@ -165,6 +183,20 @@ void KisCurveOptionWidget::updateSensorCurveLabels(KisDynamicSensorSP sensor)
     if (sensor) {
         m_curveOptionWidget->label_xmin->setText(KisDynamicSensor::minimumLabel(sensor->sensorType()));
         m_curveOptionWidget->label_xmax->setText(KisDynamicSensor::maximumLabel(sensor->sensorType(), sensor->length()));
+
+        int inMinValue = KisDynamicSensor::minimumValue(sensor->sensorType());
+        int inMaxValue = KisDynamicSensor::maximumValue(sensor->sensorType(), sensor->length());
+        QString inSuffix = KisDynamicSensor::valueSuffix(sensor->sensorType());
+
+        int outMinValue = m_curveOption->intMinValue();
+        int outMaxValue = m_curveOption->intMaxValue();
+        QString outSuffix = m_curveOption->valueSuffix();
+
+        m_curveOptionWidget->intIn->setSuffix(inSuffix);
+        m_curveOptionWidget->intOut->setSuffix(outSuffix);
+
+        m_curveOptionWidget->curveWidget->setupInOutControls(m_curveOptionWidget->intIn,m_curveOptionWidget->intOut,
+                                                         inMinValue,inMaxValue,outMinValue,outMaxValue);
     }
 }
 
@@ -185,7 +217,7 @@ void KisCurveOptionWidget::updateLabelsOfCurrentSensor()
 
 void KisCurveOptionWidget::updateValues()
 {
-    m_curveOption->setValue(m_curveOptionWidget->slider->value());
+    m_curveOption->setValue(m_curveOptionWidget->strengthSlider->value()/100.0); // convert back to 0-1 for data
     m_curveOption->setCurveUsed(m_curveOptionWidget->checkBoxUseCurve->isChecked());
     disableWidgets(!m_curveOptionWidget->checkBoxUseCurve->isChecked());
     emitSettingChanged();
@@ -297,5 +329,12 @@ void KisCurveOptionWidget::updateThemedIcons()
     m_curveOptionWidget->reverseSCurveButton->setIcon(KisIconUtils::loadIcon("curve-preset-s-reverse"));
     m_curveOptionWidget->uCurveButton->setIcon(KisIconUtils::loadIcon("curve-preset-u"));
     m_curveOptionWidget->revUCurveButton->setIcon(KisIconUtils::loadIcon("curve-preset-arch"));
+
+    // this helps make the checkboxes show themselves on the dark color themes
+    QPalette pal = m_curveOptionWidget->sensorSelector->palette();
+    QPalette newPalette = pal;
+    newPalette.setColor(QPalette::Active, QPalette::Background, pal.text().color() );
+    m_curveOptionWidget->sensorSelector->setPalette(newPalette);
+
 }
 
