@@ -34,8 +34,8 @@ public:
     KisPressureTextureStrengthOption();
     double apply(const KisPaintInformation & info) const;
 
-    void readOptionSetting(const KisPropertiesConfigurationSP setting);
-    void writeOptionSetting(KisPropertiesConfigurationSP setting) const;
+    void readOptionSetting(const KisPropertiesConfigurationSP setting) override;
+    void writeOptionSetting(KisPropertiesConfigurationSP setting) const override;
 };
 
 #endif /* __KIS_PRESSURE_TEXTURE_STRENGTH_OPTION_H */
